Module: ReactOnRailsPro
- Defined in:
- lib/react_on_rails_pro/cache.rb,
lib/react_on_rails_pro/error.rb,
lib/react_on_rails_pro/utils.rb,
lib/react_on_rails_pro/engine.rb,
lib/react_on_rails_pro/routes.rb,
lib/react_on_rails_pro/request.rb,
lib/react_on_rails_pro/version.rb,
lib/react_on_rails_pro/constants.rb,
lib/react_on_rails_pro/async_value.rb,
lib/react_on_rails_pro/stream_cache.rb,
lib/react_on_rails_pro/configuration.rb,
lib/react_on_rails_pro/stream_request.rb,
lib/react_on_rails_pro/concerns/stream.rb,
lib/react_on_rails_pro/js_code_builder.rb,
lib/react_on_rails_pro/rendering_error.rb,
lib/react_on_rails_pro/v8_log_processor.rb,
lib/react_on_rails_pro/assets_precompile.rb,
lib/react_on_rails_pro/license_validator.rb,
lib/react_on_rails_pro/license_public_key.rb,
lib/react_on_rails_pro/async_props_emitter.rb,
lib/react_on_rails_pro/renderer_cache_path.rb,
lib/react_on_rails_pro/immediate_async_value.rb,
lib/react_on_rails_pro/license_task_formatter.rb,
lib/react_on_rails_pro/renderer_cache_helpers.rb,
lib/react_on_rails_pro/pre_seed_renderer_cache.rb,
lib/react_on_rails_pro/concerns/async_rendering.rb,
lib/react_on_rails_pro/server_rendering_js_code.rb,
lib/react_on_rails_pro/rolling_deploy_cache_stager.rb,
lib/react_on_rails_pro/compression_middleware_guard.rb,
lib/react_on_rails_pro/concerns/rsc_payload_renderer.rb,
lib/react_on_rails_pro/prepare_node_renderer_bundles.rb,
lib/react_on_rails_pro/rendering_strategy/node_strategy.rb,
app/controllers/react_on_rails_pro/rsc_payload_controller.rb,
lib/react_on_rails_pro/server_rendering_pool/pro_rendering.rb,
lib/react_on_rails_pro/server_rendering_pool/node_rendering_pool.rb
Defined Under Namespace
Modules: AsyncRendering, LicensePublicKey, LicenseTaskFormatter, RSCPayloadRenderer, RendererCacheHelpers, RendererCachePath, RenderingStrategy, RollingDeployCacheStager, Routes, ServerRenderingJsCode, ServerRenderingPool, Stream, Utils, V8LogProcessor Classes: AssetsPrecompile, AsyncPropsEmitter, AsyncValue, Cache, CompressionMiddlewareGuard, Configuration, Engine, Error, ImmediateAsyncValue, JsCodeBuilder, LicenseValidator, PreSeedRendererCache, PrepareNodeRenderBundles, RenderingError, Request, RscPayloadController, StreamCache, StreamDecorator, StreamRequest
Constant Summary collapse
- VERSION =
"16.7.0.rc.0"- PROTOCOL_VERSION =
"2.0.0"- STATUS_BAD_REQUEST =
Status code 400 indicates the renderer rejected the request payload or encountered an unhandled render error.
400- STATUS_SEND_BUNDLE =
Status code 410 means to resend the request with the updated bundle.
410- STATUS_INCOMPATIBLE =
Status code 412 means protocol versions are incompatible between the server and the renderer.
412
Class Method Summary collapse
Class Method Details
.configuration ⇒ Object
.configure {|configuration| ... } ⇒ Object
4 5 6 7 |
# File 'lib/react_on_rails_pro/configuration.rb', line 4 def self.configure yield(configuration) configuration.setup_config_values end |